wags_tails.custom
=================

.. automodule:: wags_tails.custom
   :members:
   :undoc-members:
   :special-members: __init__
   :private-members:
   :exclude-members: model_fields, model_config, _abc_impl
